==> trinsic-okapi-1.5.0.tar.gz: trinsic-okapi-1.5.0/trinsicokapi/oberon.py <==
from trinsicokapi.proto.okapi.security.v1 import (
    CreateOberonKeyRequest,
    CreateOberonKeyResponse,
    CreateOberonProofRequest,
    CreateOberonProofResponse,
    CreateOberonTokenRequest,
    CreateOberonTokenResponse,
    BlindOberonTokenResponse,
    BlindOberonTokenRequest,
    UnBlindOberonTokenRequest,
    UnBlindOberonTokenResponse,
    VerifyOberonProofResponse,
    VerifyOberonProofRequest,
)
from trinsicokapi.wrapper import _typed_wrap_and_call


def create_key(request: CreateOberonKeyRequest) -> CreateOberonKeyResponse:
    return _typed_wrap_and_call("oberon_create_key", request, CreateOberonKeyResponse)


def create_proof(request: CreateOberonProofRequest) -> CreateOberonProofResponse:
    return _typed_wrap_and_call(
        "oberon_create_proof", request, CreateOberonProofResponse
    )


def create_token(request: CreateOberonTokenRequest) -> CreateOberonTokenResponse:
    return _typed_wrap_and_call(
        "oberon_create_token", request, CreateOberonTokenResponse
    )


def blind_token(request: BlindOberonTokenRequest) -> BlindOberonTokenResponse:
    return _typed_wrap_and_call("oberon_blind_token", request, BlindOberonTokenResponse)


def unblind_token(request: UnBlindOberonTokenRequest) -> UnBlindOberonTokenResponse:
    return _typed_wrap_and_call(
        "oberon_unblind_token", request, UnBlindOberonTokenResponse
    )


def verify_proof(request: VerifyOberonProofRequest) -> VerifyOberonProofResponse:
    return _typed_wrap_and_call(
        "oberon_verify_proof", request, VerifyOberonProofResponse
    )

==> trinsic-okapi-1.6.0.tar.gz: trinsic-okapi-1.6.0/trinsicokapi/oberon.py <==
from trinsicokapi.proto.okapi.security.v1 import (
    CreateOberonKeyRequest,
    CreateOberonKeyResponse,
    CreateOberonProofRequest,
    CreateOberonProofResponse,
    CreateOberonTokenRequest,
    CreateOberonTokenResponse,
    BlindOberonTokenResponse,
    BlindOberonTokenRequest,
    UnBlindOberonTokenRequest,
    UnBlindOberonTokenResponse,
    VerifyOberonProofResponse,
    VerifyOberonProofRequest,
    VerifyOberonTokenRequest,
    VerifyOberonTokenResponse,
)
from trinsicokapi.wrapper import _typed_wrap_and_call


def create_key(request: CreateOberonKeyRequest) -> CreateOberonKeyResponse:
    return _typed_wrap_and_call("oberon_create_key", request, CreateOberonKeyResponse)


def create_proof(request: CreateOberonProofRequest) -> CreateOberonProofResponse:
    return _typed_wrap_and_call(
        "oberon_create_proof", request, CreateOberonProofResponse
    )


def create_token(request: CreateOberonTokenRequest) -> CreateOberonTokenResponse:
    return _typed_wrap_and_call(
        "oberon_create_token", request, CreateOberonTokenResponse
    )


def blind_token(request: BlindOberonTokenRequest) -> BlindOberonTokenResponse:
    return _typed_wrap_and_call("oberon_blind_token", request, BlindOberonTokenResponse)


def verify_token(request: VerifyOberonTokenRequest) -> VerifyOberonTokenResponse:
    return _typed_wrap_and_call(
        "oberon_verify_token", request, VerifyOberonTokenResponse
    )


def unblind_token(request: UnBlindOberonTokenRequest) -> UnBlindOberonTokenResponse:
    return _typed_wrap_and_call(
        "oberon_unblind_token", request, UnBlindOberonTokenResponse
    )


def verify_proof(request: VerifyOberonProofRequest) -> VerifyOberonProofResponse:
    return _typed_wrap_and_call(
        "oberon_verify_proof", request, VerifyOberonProofResponse
    )
